@@ -1,5 +1,5 @@
 poislind.ll <- function(x, theta = NULL, ...){
-    if (class(x) != "table") {
+  if (!inherits(x, "table")) {
         x <- table(x)
     }
 	N <- as.numeric(x)
@@ -8,9 +8,9 @@ poislind.ll <- function(x, theta = NULL, ...){
 	if(is.null(theta)) theta <- (-(x.bar-1)+sqrt((x.bar-1)^2+8*x.bar))/(2*x.bar)
 	ll.f <- function(theta) -2*sum(N)*log(theta)-sum(N*(log(x+theta+2)-log(theta+1)*(x+3)))
 	fit <- try(suppressWarnings(stats4::mle(ll.f,start=list(theta=theta),lower=0,...)),silent=TRUE)
-	if(class(fit)=="try-error"){
+	if (inherits(fit, "try-error")){
 		fit <- try(suppressWarnings(stats4::mle(ll.f,start=list(theta=.8*theta),lower=0,...)),silent=TRUE)
-		if(class(fit)=="try-error") stop(paste("Difficulty optimizing the MLE -- must try a different starting value for theta.","\n"))
+		if (inherits(fit, "try-error")) stop(paste("Difficulty optimizing the MLE -- must try a different starting value for theta.","\n"))
 	}
 	fit
 }
